#!/usr/bin/env python

"""
OpenID redirection resources for XSLForms applications. These resources use
"root" attributes on transaction objects, and therefore should be defined within
the appropriate resources in site maps.

Copyright (C) 2006, 2007, 2008 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free
Software Foundation; either version 3 of the License, or (at your option) any
later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
details.

You should have received a copy of the GNU Lesser General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import WebStack.Resources.OpenIDRedirect # OpenIDRedirectResource

OpenIDRedirectAuthenticator = WebStack.Resources.OpenIDRedirect.OpenIDRedirectAuthenticator

class OpenIDRedirectResource(WebStack.Resources.OpenIDRedirect.OpenIDRedirectResource):

    "A redirect resource which uses dynamic knowledge about the URL space."

    def __init__(self, host, path_to_login, *args, **kw):

        """
        Initialise the resource with the 'host', 'path_to_login' (the path from
        the root of the application to the login screen), and other
        LoginRedirectResource details.

        To get the root of the application, this resource needs an attribute on
        the transaction called "root".

        Examples of 'path_to_login' with "root" attribute and result:

        "login", "/" -> "/login"
        "login", "/app/" -> "/app/login"
        "app/login", "/" -> "/app/login"
        """

        self.host = host
        self.path_to_login = path_to_login
        WebStack.Resources.OpenIDRedirect.OpenIDRedirectResource.__init__(self, *args, **kw)

    def get_app_url(self, trans):
        return self.host

    def get_login_url(self, trans):
        return self.host + trans.get_attributes()["root"] + self.path_to_login

# vim: tabstop=4 expandtab shiftwidth=4
