#!/usr/bin/env python

"An example of recursive templates."

import WebStack.Generic
from XSLForms.Resources.WebResources import \
    XSLFormsResource, input, output, resources, prepare_resources as xslforms_prepare_resources

# Site map imports.

from WebStack.Resources.Selectors import EncodingSelector

# Configuration settings.

encoding = "utf-8"

# Resource classes.

class RecursiveResource(XSLFormsResource):

    "A resource providing a recursive hierarchy of editable fields."

    resource_dir = resources(__file__)
    template_resources = {
        "recursive" : output("recursive_template.xhtml")
        }
    init_resources = {
        "recursive" : input("recursive_template.xhtml")
        }

    def select_activity(self, trans, form):
        form.set_activity("recursive")

    def respond_to_input(self, trans, form):

        # Add and remove elements according to the selectors found.

        selectors = form.get_selectors()
        self.remove_elements(selectors.get("remove"))
        self.add_elements(selectors.get("add-list"), "list")
        self.add_elements(selectors.get("add-item"), "item")

# Site map initialisation.

def get_site():

    "Return a simple Web site resource."

    # Get the main resource and the directory used by the application.

    resource = RecursiveResource()
    return EncodingSelector(resource, encoding)

# Resource preparation ahead of time - useful for making installations.

def prepare_resources():
    for cls in [RecursiveResource]:
        XSLForms.Resources.WebResources.prepare_resources(cls)

# vim: tabstop=4 expandtab shiftwidth=4
